# Changes

## 0.1.3 - 2019-12-11

* fixed problems loading lemmata data file on Windows systems

## 0.1.2 - 2019-12-06

* changed requirement Pattern to PatternLite


## 0.1.1 - 2019-01-30

* minor improvements in `find_lemma`


## 0.1.0 - 2019-01-30

* initial release on PyPI
  
